<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: updateprefs.php,v 1.23 2004/09/29 12:54:38 yeupou Exp $
#
# Copyright 1999-2000 (c) The SourceForge Crew
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../include/pre.php";
session_require(array('isloggedin'=>1));

if($user_theme == "Default") 
{ $user_theme = ""; }

if ($theme_rotate_jump == "1") 
{
  theme_rotate_jump($theme_rotate_numeric);
} 
else 
{
  setcookie("SV_THEME", $user_theme, time() + 60*60*24*365, $GLOBALS['sys_home']);
}

db_query("UPDATE user SET "
	 . "mail_siteupdates='1'," # deprecated
	 . "email_hide=" . ($form_mail_hide?"1":"0") . ","
	 . "theme='" . $user_theme . "' WHERE "
	 . "user_id=" . user_getid());

session_redirect($GLOBALS['sys_home'] . "account/");

?>
